Package: AnVILAz
Title: R / Bioconductor Support for the AnVIL Azure Platform
Version: 1.7.2
Date: 2026-05-26
Authors@R: 
    c(person(
        "Martin", "Morgan", role = c("aut", "ctb"),
        email = "mtmorgan.bioc@gmail.com",
        comment = c(ORCID = "0000-0002-5874-8148")
    ),
    person(
        "Marcel", "Ramos", role = c("aut", "cre"),
        email = "marcel.ramos@sph.cuny.edu",
        comment = c(ORCID = "0000-0002-3242-0582")
    ))
Description: The AnVIL is a cloud computing resource developed in part
    by the National Human Genome Research Institute. The AnVILAz
    package supports end-users and developers using the AnVIL platform
    in the Azure cloud. The package provides a programmatic interface
    to AnVIL resources, including workspaces, notebooks, tables, and
    workflows. The package also provides utilities for managing
    resources, including copying files to and from Azure Blob Storage,
    and creating shared access signatures (SAS) for secure access to
    Azure resources.
License: Artistic-2.0
Encoding: UTF-8
Depends: R (>= 4.5.0)
Imports: AnVILBase, BiocBaseUtils, curl, httr2, jsonlite, methods,
        rjsoncons, tibble, utils
biocViews: Software, Infrastructure, ThirdPartyClient
Roxygen: list(markdown = TRUE)
Suggests: BiocStyle, dplyr, knitr, readr, rmarkdown, tinytest
SystemRequirements: az, azcopy
BugReports: https://github.com/Bioconductor/AnVILAz/issues
URL: https://github.com/Bioconductor/AnVILAz
VignetteBuilder: knitr
Collate: 'AnVILAz-package.R' 'authentication.R' 'azure-class.R'
        'avnotebooks-methods.R' 'avtable-methods.R'
        'avworkflow-methods.R' 'avworkspace-methods.R' 'az-utilities.R'
        'az_copy-helpers.R' 'az_sas_token.R' 'azure-methods.R'
        'has_avworkspace-methods.R' 'resources.R' 'utilities.R'
        'workspace-dev-ops.R' 'workspace_env.R' 'zzz.R'
Config/roxygen2/version: 8.0.0
git_url: https://git.bioconductor.org/packages/AnVILAz
git_branch: devel
git_last_commit: 89e3a4b
git_last_commit_date: 2026-05-26
Repository: Bioconductor 3.24
Date/Publication: 2026-06-01
NeedsCompilation: no
Packaged: 2026-06-01 21:14:11 UTC; biocbuild
Author: Martin Morgan [aut, ctb] (ORCID:
    <https://orcid.org/0000-0002-5874-8148>),
  Marcel Ramos [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3242-0582>)
Maintainer: Marcel Ramos <marcel.ramos@sph.cuny.edu>
