# Generated by roxygen2: do not edit by hand

S3method(as.logical,azcopyStatus)
S3method(print,azcopyStatus)
S3method(summary,azcopyStatus)
export(avworkflow_jobs_inputs)
export(az_exists)
export(az_health_check)
export(az_sas_token)
export(azure)
export(cbas_url)
export(wds_api_version)
export(workspace_data_service_url)
export(workspace_id)
export(workspace_storage_cont_id)
export(workspace_storage_cont_url)
exportClasses(azure)
exportMethods(avbackup)
exportMethods(avcopy)
exportMethods(avlist)
exportMethods(avnotebooks)
exportMethods(avnotebooks_delocalize)
exportMethods(avnotebooks_localize)
exportMethods(avremove)
exportMethods(avrestore)
exportMethods(avstorage)
exportMethods(avtable)
exportMethods(avtable_delete)
exportMethods(avtable_delete_values)
exportMethods(avtable_import)
exportMethods(avtable_import_set)
exportMethods(avtables)
exportMethods(avworkflow_jobs)
exportMethods(avworkspace)
exportMethods(avworkspace_clone)
exportMethods(avworkspace_name)
exportMethods(avworkspace_namespace)
exportMethods(avworkspaces)
exportMethods(has_avworkspace)
importClassesFrom(AnVILBase,Platform)
importFrom(AnVILBase,avbackup)
importFrom(AnVILBase,avcopy)
importFrom(AnVILBase,avlist)
importFrom(AnVILBase,avnotebooks)
importFrom(AnVILBase,avnotebooks_delocalize)
importFrom(AnVILBase,avnotebooks_localize)
importFrom(AnVILBase,avremove)
importFrom(AnVILBase,avrestore)
importFrom(AnVILBase,avstorage)
importFrom(AnVILBase,avtable)
importFrom(AnVILBase,avtable_delete)
importFrom(AnVILBase,avtable_delete_values)
importFrom(AnVILBase,avtable_import)
importFrom(AnVILBase,avtable_import_set)
importFrom(AnVILBase,avtables)
importFrom(AnVILBase,avworkflow_jobs)
importFrom(AnVILBase,avworkspace)
importFrom(AnVILBase,avworkspace_clone)
importFrom(AnVILBase,avworkspace_name)
importFrom(AnVILBase,avworkspace_namespace)
importFrom(AnVILBase,avworkspaces)
importFrom(AnVILBase,cloud_platform)
importFrom(AnVILBase,has_avworkspace)
importFrom(BiocBaseUtils,isCharacter)
importFrom(BiocBaseUtils,isScalarCharacter)
importFrom(BiocBaseUtils,isScalarLogical)
importFrom(httr2,req_auth_bearer_token)
importFrom(httr2,req_body_json)
importFrom(httr2,req_body_multipart)
importFrom(httr2,req_cache)
importFrom(httr2,req_headers)
importFrom(httr2,req_method)
importFrom(httr2,req_perform)
importFrom(httr2,req_template)
importFrom(httr2,req_url_query)
importFrom(httr2,request)
importFrom(httr2,resp_body_json)
importFrom(httr2,resp_body_string)
importFrom(httr2,resp_is_error)
importFrom(jsonlite,fromJSON)
importFrom(methods,new)
importFrom(rjsoncons,jmespath)
importFrom(utils,URLencode)
importFrom(utils,stack)
importFrom(utils,write.table)
