
# AnVILAz

<!-- badges: start -->
<!-- badges: end -->

The AnVIL is a cloud computing resource developed in part
    by the National Human Genome Research Institute. The AnVILAz
    package supports end-users and developers using the AnVIL platform
    in the Azure cloud.

## Installation

You can install the development version of AnVILAz like so:

``` r
if (!requireNamespace("BiocManager", quietly = TRUE))
    install.packages("BiocManager", repos = "https://cran.r-project.org")
BiocManager::install("Bioconductor/AnVILAz")
```

## Example

This is a basic example which shows you how to solve a common problem:

``` r
library(AnVILAz)
```

