#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom httr2 request
#' @importFrom httr2 req_auth_bearer_token req_headers req_cache req_perform
#' @importFrom httr2 req_method req_template req_body_multipart req_body_json
#' @importFrom httr2 resp_is_error req_url_query
#' @importFrom httr2 resp_body_string resp_body_json
## usethis namespace: end
NULL
